Welcome to bs_ds's documentation!
======================================
.. image:: bs_ds_logo.png
    :width: 400px

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   bs_ds
   installation
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
